import typing

GenericType = typing.TypeVar("GenericType")

def edges_from_elem(ele):
    """ """

    ...

def elems_depth_measure(ele_dst, ele_src, other_edges_over_cb):
    """ """

    ...

def elems_depth_search(ele_init, depths, other_edges_over_cb, results_init):
    """ """

    ...

def find_next(ele_dst, ele_src):
    """ """

    ...

def other_edges_over_edge(e):
    """ """

    ...

def other_edges_over_face(e):
    """ """

    ...

def select_next(bm, report):
    """ """

    ...

def select_prev(bm, report):
    """ """

    ...

def verts_from_elem(ele):
    """ """

    ...
