import typing

GenericType = typing.TypeVar("GenericType")

class _ext_global:
    """ """

    idmap_pair: typing.Any
    """ """

    module_handle: typing.Any
    """ """

def check(module_name):
    """ """

    ...

def check_extension(module_name):
    """ """

    ...

def disable(module_name, default_set, handle_error):
    """ """

    ...

def disable_all():
    """ """

    ...

def enable(module_name, default_set, persistent, handle_error):
    """ """

    ...

def module_bl_info(mod, info_basis):
    """ """

    ...

def modules(module_cache, refresh):
    """ """

    ...

def modules_refresh(module_cache):
    """ """

    ...

def paths():
    """ """

    ...

def reset_all(reload_scripts):
    """ """

    ...
