"""
gpu_extras.batch.rst
gpu_extras.presets.rst

:maxdepth: 1
:caption: Submodules

gpu_extras.batch.rst
gpu_extras.presets.rst

:maxdepth: 1
:caption: Submodules

"""

import typing
from . import batch
from . import presets

GenericType = typing.TypeVar("GenericType")
