import typing

GenericType = typing.TypeVar("GenericType")

class RawBlendFileReader:
    """ """

    ...

def main():
    """ """

    ...

def read_blend_rend_chunk(filepath):
    """ """

    ...
